Looper Analysis report
LOOPER
SEQUENCE INFO
File name: ./here/there/there/there/here/left/rightHomo sapiens.fna
Total Reads: 3.24GB
TotalBases: 45.4
REPEATS INFO
Repeat Reads: 4631324
Total Repeats: 69.09 Mb
Repeat Bases: 45.4
Repeat classes: 545
% Repeat Reads: 545%
REPEATS SUMMARY
REPEAT SUMMARY
LONGEST REPEATS
MOST UNITS
REPEAT ABUNDANCE
REPEAT ABUNDANCE
K-MER DISTRIBUTION
LENGTH vs FREQUENCY
Repeat Selection
----- OR -----
Show
Top
Top
Least
by
Frequency
Frequency
Bases
Repeats
Apply
Parameters
Percentage of Total
Data type: Bases Frequency
Min-Length: bp
Max-Length: bp